pub type Worker = WorkerLoop;Expand description
Type alias for API continuity with callers that use the old Worker name.
Aliased Type
pub struct Worker { /* private fields */ }pub type Worker = WorkerLoop;Type alias for API continuity with callers that use the old Worker name.
pub struct Worker { /* private fields */ }